<?php
/*-----------------------------------------------------------------------------------
	Plugin Name: Academy - Event Widget
	Plugin URI: http://www.membersiteacademy.com
	Description: Displays upcoming event with calendar link.
	Version: 1.0
	Author: Mike Morrison
	Author URI: http://www.wedowp.co.uk
-----------------------------------------------------------------------------------*/

if(!class_exists('Academy_Theme_Widget_Event')) {


add_action( 'widgets_init', 'register_widget_event' ); // function to load my widget
 
function register_widget_event() {
	register_widget( 'Academy_Theme_Widget_Event' );
}

 
class Academy_Theme_Widget_Event extends WP_Widget {
 
	function __construct() {
	    $widget_ops = array( 'classname' => 'academy_theme_widget_event_class', 'description' => 'A widget that displays an upcoming event with add to calendar links' );
	    $control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'academy_theme_event' );
	    $id_base="academy_theme_event";
	    $id_name='Memberoni: Event Widget';
	    parent::__construct($id_base, $id_name, $widget_ops, $control_ops );
	}

	function widget( $args, $instance ) {

		extract( $args );
		$atctitle = isset($instance['atctitle']) ? $instance['atctitle'] : 'Add to Calendar' ;
		$title = $instance['title'];
		$content = $instance['content'];
		$timezone = $instance['timezone'];
		$startdate = $instance['startdate'];
		$enddate = $instance['enddate'];
		$eventlink = $instance['eventlink'] ? $instance['eventlink'] : site_url();
		?>

			<link href="//addtocalendar.com/atc/1.5/atc-style-menu-wb.css" rel="stylesheet" type="text/css">

		    <script type="text/javascript">(function () {
		            if (window.addtocalendar)if(typeof window.addtocalendar.start == "function")return;
		            if (window.ifaddtocalendar == undefined) { window.ifaddtocalendar = 1;
		                var d = document, s = d.createElement('script'), g = 'getElementsByTagName';
		                s.type = 'text/javascript';s.charset = 'UTF-8';s.async = true;
		                s.src = ('https:' == window.location.protocol ? 'https' : 'http')+'://addtocalendar.com/atc/1.5/atc.min.js';
		                var h = d[g]('body')[0];h.appendChild(s); }})();
		    </script>

			<aside class="sidebar_orange next_training">
				<h3><?php echo $title; ?></h3>
				<?php if ($content) : ?><p><?php echo $content; ?></p><?php endif; ?>

			    <div>

			    <!-- 3. Place event data -->
			    <span class="addtocalendar atc-style-menu-wb">
			    	<a class="atcb-link"><?php if (isset($atctitle)) : echo $atctitle; else: echo 'Add to Calendar'; endif; ?></a>
			        <var class="atc_event">
			            <var class="atc_date_start"><?php echo $startdate; ?></var>
			            <var class="atc_date_end"><?php echo $enddate; ?></var>
			            <var class="atc_timezone"><?php echo $timezone; ?></var>
			            <var class="atc_title"><?php echo $title; ?></var>
			            <var class="atc_description"><?php echo $content; ?></var>
			            <var class="atc_location"><?php echo $eventlink; ?></var>
			        </var>
			    </span>			
			    </div>	

			</aside>
<?php
		 

	}
	 
	function update( $new_instance, $old_instance ) {
	    $instance = $old_instance;
	 
	    //Strip tags from title and name to remove HTML
	    $instance['atctitle'] = $new_instance['atctitle'];
	    $instance['title'] = $new_instance['title'];
	    $instance['content'] = $new_instance['content'];
	    $instance['timezone'] = $new_instance['timezone'];
	    $instance['startdate'] = date("Y-m-d H:i:s",strtotime($new_instance['startdate']));
	    $instance['enddate'] = date("Y-m-d H:i:s",strtotime($new_instance['enddate']));
	    $instance['eventlink'] = $new_instance['eventlink'];
	    return $instance;
	}
	 
	function form(	$instance ) {

		//Set up some default widget settings.
		$defaults = array( 'title' => '', 'content' => '', 'eventlink' => '', 'timezone' => 'UTC', 'startdate' => date("Y-m-d H:i:s"), 'enddate' => date("Y-m-d H:i:s",strtotime("+ 1 hour")));
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<p>
		    <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Event Title:', 'example'); ?></label>
		    <input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" style="width:100%;" />
		</p>
		<p>
		    <label for="<?php echo $this->get_field_id( 'content' ); ?>"><?php _e('Event Description:', 'example'); ?></label>
		    <input id="<?php echo $this->get_field_id( 'content' ); ?>" name="<?php echo $this->get_field_name( 'content' ); ?>" value="<?php echo $instance['content']; ?>" style="width:100%;" />
		</p>
		<p>
		    <label for="<?php echo $this->get_field_id( 'eventlink' ); ?>"><?php _e('Event URL:', 'example'); ?></label>
		    <input id="<?php echo $this->get_field_id( 'eventlink' ); ?>" name="<?php echo $this->get_field_name( 'eventlink' ); ?>" value="<?php echo $instance['eventlink']; ?>" style="width:100%;" placeholder="<?php echo site_url(); ?>" />	
		</p>
		<p>
		    <label for="<?php echo $this->get_field_id( 'startdate' ); ?>"><?php _e('Start Date/Time:', 'example'); ?></label>
		    <input id="<?php echo $this->get_field_id( 'startdate' ); ?>" name="<?php echo $this->get_field_name( 'startdate' ); ?>" value="<?php echo $instance['startdate']; ?>" style="width:100%;" placeholder="YYYY-MM-DD HH:MM:SS" />
		    <em>YYYY-MM-DD HH:MM:SS</em>
		</p>
		<p>
		    <label for="<?php echo $this->get_field_id( 'enddate' ); ?>"><?php _e('End Date/Time:', 'example'); ?></label>
		    <input id="<?php echo $this->get_field_id( 'enddate' ); ?>" name="<?php echo $this->get_field_name( 'enddate' ); ?>" value="<?php echo $instance['enddate']; ?>" style="width:100%;" placeholder="YYYY-MM-DD HH:MM:SS" />	
		    <em>YYYY-MM-DD HH:MM:SS</em>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('timezone'); ?>"><?php _e('Choose Timezone:','example'); ?></label>
			<select id="<?php echo $this->get_field_id( 'timezone' ); ?>" name="<?php echo $this->get_field_name( 'timezone' ); ?>" style="width:100%;">
				<?php 
				include(get_template_directory() . '/includes/resources/timezones.rsrc.php');
				foreach ($timezone_countries_array as $key=>$value) :
					echo (($key==$instance['timezone']) ? '<option value="' . $key . '" selected="selected">' . $value . '</option>' : '<option value="' . $key . '">' . $value . '</option>');
				endforeach; 
				?>
			</select>
		</p>
		<p>
		    <label for="<?php echo $this->get_field_id( 'atctitle' ); ?>"><?php _e('Button label:', 'example'); ?></label>
		    <input id="<?php echo $this->get_field_id( 'atctitle' ); ?>" name="<?php echo $this->get_field_name( 'atctitle' ); ?>" value="<?php if (isset($instance['atctitle'])) : echo $instance['atctitle']; else: echo 'Add to Calendar'; endif; ?>" style="width:100%;" />
		</p>





<?php

	}

}

}